# Changes

Version 1.2.1 (2021-01-06)

We closed a total of 19 issues (enhancements and bug fixes) through 7 pull requests, since our last release on 2020-12-30.

## Issues Closed
  - Docs To Do (#54)
  - Missing classes in API docs (#63)
  - notebook and API docs cleanup (#64)
  - Add tutorials to docs (#60)
  - Travis --> GHA (#56)
  - CI with GitHub Actions (#55)
  - Migrate from RTD to GH-pages for automated doc builds and hosting (#53)
  - update env variable syntax (#52)
  - Spatial dependence diagnostics returns nan (#47)
  - Random Effects for Spatial Panels (#46)
  - Random Effects Panel (#50)
  - Add GM_Lag_example notebook (#38)

## Pull Requests
  - notebook and API docs cleanup (#64)
  - Add tutorials to docs (#60)
  - CI with GitHub Actions (#55)
  - Migrate from RTD to GH-pages for automated doc builds and hosting (#53)
  - update env variable syntax (#52)
  - Random Effects Panel (#50)
  - Add GM_Lag_example notebook (#38)

The following individuals contributed to this release:

  - James Gaboardi
  - Pedro Amaral